## Version 0.0.8

This new version 0.0.8 of Llamabot introduces enhanced functionality and improved documentation.

### New Features

- The application now exposes more arguments, providing users with greater flexibility and control. (f42815) (Eric Ma)
- Additional docstrings have been added, improving the documentation and making the code easier to understand and use. (f42815) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
